searchData={"content_type":"text/markdown","items":[{"doc":"IBMId Strategy for Überauth.","ref":"Ueberauth.Strategy.IBMId.html","title":"Ueberauth.Strategy.IBMId","type":"module"},{"doc":"Includes the credentials from the IBMId response.","ref":"Ueberauth.Strategy.IBMId.html#credentials/1","title":"Ueberauth.Strategy.IBMId.credentials/1","type":"function"},{"doc":"","ref":"Ueberauth.Strategy.IBMId.html#default_options/0","title":"Ueberauth.Strategy.IBMId.default_options/0","type":"function"},{"doc":"Stores the raw information (including the token) obtained from the IBMId callback.","ref":"Ueberauth.Strategy.IBMId.html#extra/1","title":"Ueberauth.Strategy.IBMId.extra/1","type":"function"},{"doc":"Handles initial request for IBMId authentication.","ref":"Ueberauth.Strategy.IBMId.html#handle_request!/1","title":"Ueberauth.Strategy.IBMId.handle_request!/1","type":"function"},{"doc":"Fetches the fields to populate the info section of the `Ueberauth.Auth` struct.","ref":"Ueberauth.Strategy.IBMId.html#info/1","title":"Ueberauth.Strategy.IBMId.info/1","type":"function"},{"doc":"Fetches the uid field from the response.","ref":"Ueberauth.Strategy.IBMId.html#uid/1","title":"Ueberauth.Strategy.IBMId.uid/1","type":"function"},{"doc":"OAuth2 for IBMId.\n\nAdd `client_id` and `client_secret` to your configuration:\n\nconfig :ueberauth, Ueberauth.Strategy.IBMId.OAuth,\n  client_id: System.get_env(\"IBMID_OIDC_CLIENT_ID\"),\n  client_secret: System.get_env(\"IBMID_OIDC_CLIENT_SECRET\")","ref":"Ueberauth.Strategy.IBMId.OAuth.html","title":"Ueberauth.Strategy.IBMId.OAuth","type":"module"},{"doc":"","ref":"Ueberauth.Strategy.IBMId.OAuth.html#authorize_url/2","title":"Ueberauth.Strategy.IBMId.OAuth.authorize_url/2","type":"function"},{"doc":"Provides the authorize url for the request phase of Ueberauth.\nNo need to call this usually.","ref":"Ueberauth.Strategy.IBMId.OAuth.html#authorize_url!/2","title":"Ueberauth.Strategy.IBMId.OAuth.authorize_url!/2","type":"function"},{"doc":"Construct a client for requests to IBMId.\nThis will be setup automatically for you in `Ueberauth.Strategy.IBMId`.\nThese options are only useful for usage outside the normal callback phase\nof Ueberauth.","ref":"Ueberauth.Strategy.IBMId.OAuth.html#client/1","title":"Ueberauth.Strategy.IBMId.OAuth.client/1","type":"function"},{"doc":"","ref":"Ueberauth.Strategy.IBMId.OAuth.html#get/4","title":"Ueberauth.Strategy.IBMId.OAuth.get/4","type":"function"},{"doc":"","ref":"Ueberauth.Strategy.IBMId.OAuth.html#get_token/3","title":"Ueberauth.Strategy.IBMId.OAuth.get_token/3","type":"function"},{"doc":"","ref":"Ueberauth.Strategy.IBMId.OAuth.html#get_token!/2","title":"Ueberauth.Strategy.IBMId.OAuth.get_token!/2","type":"function"},{"doc":"# Überauth IBMId\n\n> IBMId OAuth2 strategy for Überauth.","ref":"readme.html","title":"Überauth IBMId","type":"extras"},{"doc":"1. Setup your application with IBM Security Verify to get a Client ID and Secret. Ensure that a callback URL is specified in the OpenID Connect configuration (i.e. `https://localhost:PORT/auth/ibmid/callback`). [Learn more about IBM Security Verify & OpenID Connect](https://www.ibm.com/docs/en/security-verify?topic=sign-configuring-single-in-openid-connect-provider).\n\nNOTE: IBMId only allows HTTPS callback URLs. [Learn how to serve a Phoenix App locally with HTTPS](https://til.hashrocket.com/posts/b8p5oalouz--serve-phoenix-app-locally-with-https-).\n\n1. Add `:ueberauth_ibmid` to your list of dependencies in `mix.exs`:\n\n   ```elixir\n   def deps do\n    [\n      ...\n\n      {:ueberauth_ibmid, \"~> 0.1.0\"}\n\n      ...\n    ]\n   end\n   ```\n\n1. Add IBMId to your Überauth configuration:\n\n   ```elixir\n   config :ueberauth, Ueberauth,\n     providers: [\n       ibmid: {Ueberauth.Strategy.IBMId, []}\n     ]\n   ```\n\n1. Update your provider configuration:\n\n   ```elixir\n   config :ueberauth, Ueberauth.Strategy.IBMId.OAuth,\n     client_id: System.get_env(\"IBMID_OIDC_CLIENT_ID\"),\n     client_secret: System.get_env(\"IBMID_OIDC_CLIENT_SECRET\")\n   ```\n\n   Or, to read the client credentials at runtime\n\n   ```elixir\n   config :ueberauth, Ueberauth.Strategy.IBMId.OAuth,\n     client_id: {:system, \"IBMID_OIDC_CLIENT_ID\"},\n     client_secret: {:system, \"IBMID_OIDC_CLIENT_SECRET\"}\n   ```\n\n1. Include the Überauth plug in your controller:\n\n   ```elixir\n   defmodule MyApp.Router do\n     use MyApp.Web, :router\n\n\n     pipeline :browser do\n       plug Ueberauth\n       ...\n     end\n   end\n   ```\n\n1. Create the request and callback routes if you haven't already:\n\n   ```elixir\n   scope \"/auth\", MyApp do\n     pipe_through :browser\n\n     get \"/:provider\", AuthController, :request\n     get \"/:provider/callback\", AuthController, :callback\n   end\n   ```\n\n1. Your controller needs to implement callbacks to deal with `Ueberauth.Auth` and `Ueberauth.Failure` responses.","ref":"readme.html#installation","title":"Installation - Überauth IBMId","type":"extras"},{"doc":"You can initialize the request through:\n\n/auth/ibmid\n\nBy default the requested scope is \"openid\", which also happens to be the only required scope. Scope can be configured explicitly in your configuration (see below). [Learn more about OIDC scopes](https://auth0.com/docs/scopes/openid-connect-scopes).\n\n```elixir\nconfig :ueberauth, Ueberauth,\n  providers: [\n    ibmid: {Ueberauth.Strategy.IBMId, [default_scope: \"openid profile\"]}\n  ]\n```","ref":"readme.html#calling","title":"Calling - Überauth IBMId","type":"extras"},{"doc":"Please see [LICENSE](https://github.com/schwarz/ueberauth_ibmid/blob/master/LICENSE) for licensing details.","ref":"readme.html#license","title":"License - Überauth IBMId","type":"extras"}],"producer":{"name":"ex_doc","version":[48,46,51,52,46,48]}}